// Andrew Gooch and Greg Huber
// How Issue Positions Affect Candidate Performance
// July 2018

// This code appends the mass public survey with the donors survey
// Before appending, both data files recode variables to match both data files
// Recodes also include indicator variables for the two regression models (primary and general election voting)
// Finaly, a new DTA file is created with both mass public and donor respondents, which is then used to create the main analysis: Figures 2 to 5 and Tables 3 and 4
set more off
clear
cd "..\Data\Data for Analysis"
use Mass_Public_Cleaned


drop if pid7==0
gen Sample = 1
label var Sample "Which Sample? Mass=1, Donor==2"

* Treatment indicators
gen T_Extreme = 0
replace T_Extreme = 1 if group_numeric == 2
label var T_Extreme "Extreme treatment"

gen T_Unusual = 0
replace T_Unusual = 1 if group_numeric == 3
label var T_Unusual "Inconsistent treatment"

gen T_Bipartisan = 0
replace T_Bipartisan = 1 if group_numeric == 4
label var T_Bipartisan "Bipartisan treatment"

gen T_Aligned = 0
replace T_Aligned = 1 if group_numeric == 1
label var T_Aligned "Aligned treatment"

*saw a dem candidate
gen Dem_cand = 0
replace Dem_cand = 1 if pid_candidate == "dem"
label var Dem_cand "Shown Democratic candidate"

* Partisanship
gen dem_d = 0
replace dem_d = 1 if pid3 == -1

gen rep_d = 0
replace rep_d = 1 if pid3 == 1

gen ind_d = 0
replace ind_d = 1 if pid3 == 0
label var ind_d "Pure Independents"

gen dem_lean = 0
replace dem_lean = 1 if pid7 == -1
label var dem_lean "Leaning Democrat"

gen dem_weak = 0
replace dem_weak = 1 if pid7 == -2
label var dem_weak "Weak Democrat"

gen rep_lean = 0
replace rep_lean = 1 if pid7 == 1
label var rep_lean "Leaning Republican"

gen rep_weak = 0
replace rep_weak = 1 if pid7 == 2
label var rep_weak "Weak Republican"

gen rep_strong = 0
replace rep_strong = 1 if pid7 == 3
label var rep_strong "Strong Republican"

gen strong_partisan = 0
replace strong_partisan = 1 if pid7 == -3 | pid7 == 3
label var strong_partisan "Strong Partisans"

gen weak_partisan = 0
replace weak_partisan = 1 if pid7 == -2 | pid7 == 2
label var weak_partisan "Weak Partisans"

gen lean_partisan = 0
replace lean_partisan = 1 if pid7 == -1 | pid7 == 1
label var lean_partisan "Lean Partisans"

// dummy vars for marks of competences. for regression, manager with 10 employees is excluded category

gen manager_10_sl = 0
replace manager_10_sl = 1 if marks_of_competency_main == "a manager of a company with 10 employees and was a member of the state legislature."
label var manager_10_sl "10 Employees, State Legislature"

gen manager_10_cc = 0
replace manager_10_cc = 1 if marks_of_competency_main == "a manager of a company with 10 employees and was a member of the city council."
label var manager_10_cc "10 Employees, City Council"

gen manager_100 = 0
replace manager_100 = 1 if marks_of_competency_main == "a manager of a company with 100 employees."
label var manager_100 "100 Employees"

gen manager_100_sl = 0
replace manager_100_sl = 1 if marks_of_competency_main == "a manager of a company with 100 employees and was a member of the state legislature."
label var manager_100_sl "100 Employees, State Legislature"

gen manager_100_cc = 0
replace manager_100_cc = 1 if marks_of_competency_main == "a manager of a company with 100 employees and was a member of the city council."
label var manager_100_cc "100 Employees, City Council"

// note spelling error on randomized insert (1 in 9 chance of getting a spelling error. Fixed in donor study)
gen manager_1000 = 0
replace manager_1000 = 1 if marks_of_competency_main == "a manger of a company with 1000 employees." 
label var manager_1000 "1000 Employees"

gen manager_1000_sl = 0
replace manager_1000_sl = 1 if marks_of_competency_main == "a manager of a company with 1000 employees and was a member of the state legislature."
label var manager_1000_sl "1000 Employees, State Legislature"

gen manager_1000_cc = 0
replace manager_1000_cc = 1 if marks_of_competency_main == "a manager of a company with 1000 employees and was a member of the city council."
label var manager_1000_cc "1000 Employees, City Council"

gen election = ""
replace election = "lose" if district_competitiveness_main == "likely to lose in the general (November) election"
replace election = "toss up" if district_competitiveness_main == "about equally likely to win or lose in the general (November) election"
replace election = "win" if district_competitiveness_main == "likely to win in the general (November) election"


//generate dummy variable for seeing liberal (conservative) vs. somewhat liberal (conservative) issue positions (1=lib, 0=somewhat lib)
gen guns_lib_d = 0
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group_numeric == 1 & pid_candidate == "dem" 
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group_numeric == 2 & pid_candidate == "dem" 
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group_numeric == 3 & pid_candidate == "dem" 
replace guns_lib_d = 1 if Guns_insert_aligned_dem_main == "I support “no-issue” concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." & group_numeric == 4 & pid_candidate == "dem"  
label var guns_lib_d "Guns: liberal position"

gen taxes_lib_d = 0
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group_numeric == 1 & pid_candidate == "dem" 
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group_numeric == 2 & pid_candidate == "dem"  
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group_numeric == 3 & pid_candidate == "dem"  
replace taxes_lib_d = 1 if Taxes_insert_aligned_dem_main == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000." & group_numeric == 4 & pid_candidate == "dem"  
label var taxes_lib_d "Taxes: liberal position"

gen SS_lib_d = 0
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group_numeric == 1 & pid_candidate == "dem"  
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group_numeric == 2 & pid_candidate == "dem"  
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group_numeric == 3 & pid_candidate == "dem"  
replace SS_lib_d = 1 if SS_insert_aligned_dem_main == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." & group_numeric == 4 & pid_candidate == "dem"  
label var SS_lib_d "Social Security: liberal position"

gen Abort_lib_d = 0
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group_numeric == 1 & pid_candidate == "dem"  
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group_numeric == 2 & pid_candidate == "dem"  
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group_numeric == 3 & pid_candidate == "dem"  
replace Abort_lib_d = 1 if Abort_insert_aligned_dem_main == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent." & group_numeric == 4 & pid_candidate == "dem"  
label var Abort_lib_d "Abortion: liberal position"

gen Welfare_lib_d = 0
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group_numeric == 1 & pid_candidate == "dem"  
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group_numeric == 2 & pid_candidate == "dem"  
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group_numeric == 3 & pid_candidate == "dem"  
replace Welfare_lib_d = 1 if Welfare_insert_aligned_dem_main == "I support raising the lifetime cap from 5 years to 9 years." & group_numeric == 4 & pid_candidate == "dem"  
label var Welfare_lib_d "Welfare: liberal position"

gen ISIS_lib_d = 0
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group_numeric == 1 & pid_candidate == "dem"  
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group_numeric == 2 & pid_candidate == "dem"  
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group_numeric == 3 & pid_candidate == "dem"  
replace ISIS_lib_d = 1 if ISIS_insert_aligned_dem_main == "I do not support sending additional air power or any ground troops to Syria and Iraq." & group_numeric == 4 & pid_candidate == "dem"  
label var ISIS_lib_d "ISIS: liberal position"

gen guns_con_d = 0
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group_numeric == 1 & pid_candidate == "rep" 
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group_numeric == 2 & pid_candidate == "rep" 
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group_numeric == 3 & pid_candidate == "rep" 
replace guns_con_d = 1 if Guns_insert_aligned_rep_main == "I support “unrestricted” concealed carry gun laws. These laws do not require a permit to carry a concealed handgun." & group_numeric == 4 & pid_candidate == "rep"  
label var guns_con_d "Guns: conservative position"

gen taxes_con_d = 0
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group_numeric == 1 & pid_candidate == "rep"
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group_numeric == 2 & pid_candidate == "rep"  
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group_numeric == 3 & pid_candidate == "rep"  
replace taxes_con_d = 1 if Taxes_insert_aligned_rep_main == "I support reducing the top marginal tax rate to 20%." & group_numeric == 4 & pid_candidate == "rep"  
label var taxes_con_d "Taxes: conservative position"

gen SS_con_d = 0
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group_numeric == 1 & pid_candidate == "rep"  
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group_numeric == 2 & pid_candidate == "rep"  
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group_numeric == 3 & pid_candidate == "rep"  
replace SS_con_d = 1 if SS_insert_aligned_rep_main == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%." & group_numeric == 4 & pid_candidate == "rep"  
label var SS_con_d "Social Security: conservative position"

gen Abort_con_d = 0
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group_numeric == 1 & pid_candidate == "rep"  
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group_numeric == 2 & pid_candidate == "rep"  
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group_numeric == 3 & pid_candidate == "rep"  
replace Abort_con_d = 1 if Abort_insert_aligned_rep_main == "I support making abortion legal only in cases where the mother’s life is in danger." & group_numeric == 4 & pid_candidate == "rep"  
label var Abort_con_d "Abortion: conservative position"

gen Welfare_con_d = 0
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group_numeric == 1 & pid_candidate == "rep" 
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group_numeric == 2 & pid_candidate == "rep"  
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group_numeric == 3 & pid_candidate == "rep"  
replace Welfare_con_d = 1 if Welfare_insert_aligned_rep_main == "I support reducing the lifetime cap from 5 years to 1 year." & group_numeric == 4 & pid_candidate == "rep"  
label var Welfare_con_d "Welfare: conservative position"

gen ISIS_con_d = 0
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group_numeric == 1 & pid_candidate == "rep"
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group_numeric == 2 & pid_candidate == "rep"  
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group_numeric == 3 & pid_candidate == "rep"  
replace ISIS_con_d = 1 if ISIS_insert_aligned_rep_main == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq." & group_numeric == 4 & pid_candidate == "rep"  
label var ISIS_con_d "ISIS: conservative position"


// generate dummy variables for seeing each issue area
gen Guns_inserts = 0 
replace Guns_inserts = 1 if three_issues == "G Ab T" | three_issues == "G I Ab" | three_issues == "G I SS" | three_issues == "G I T" |  three_issues == "G SS Ab" | three_issues == "G SS T" | three_issues == "G W Ab" | ///
three_issues == "G W I" | three_issues == "G W SS" | three_issues == "G W T" 
label var Guns_inserts "Guns issue area displayed"

gen Abortion_inserts = 0 
replace Abortion_inserts = 1 if three_issues == "G Ab T" | three_issues == "G I Ab" | three_issues == "G SS Ab " | three_issues == "G W Ab " |  three_issues == "I Ab T" | three_issues == "I SS Ab" | three_issues == "SS Ab T" | ///
three_issues == "W Ab T" | three_issues == "W I Ab" | three_issues == "W SS Ab" 
label var Abortion_inserts "Abortion issue area displayed"

gen Taxes_inserts = 0 
replace Taxes_inserts = 1 if three_issues == " G I Ab" | three_issues == "G I SS" | three_issues == "G I T" | three_issues == "G W I"  |  three_issues == "I Ab T" | three_issues == "I SS T" | three_issues == "SS Ab T" | ///
three_issues == "W Ab T" | three_issues == "W I T" | three_issues == "W SS T" 
label var Taxes_inserts "Taxes issue area displayed"

gen ISIS_inserts = 0 
replace ISIS_inserts = 1 if three_issues == "G I Ab" | three_issues == "G I SS" | three_issues == "G I T" | three_issues == "G W I"  |  three_issues == "I Ab T" | three_issues == "I SS Ab" | three_issues == "I SS T" | ///
three_issues == "W I Ab" | three_issues == "W I SS" | three_issues == "W I T" 
label var ISIS_inserts "ISIS issue area displayed"

gen SocialSecurity_inserts = 0 
replace SocialSecurity_inserts = 1 if three_issues == "G I SS" | three_issues == "G SS Ab" | three_issues == "G SS T" | three_issues == "G W SS"  |  three_issues == "I SS Ab" | three_issues == "I SS T" | three_issues == "SS Ab T" | ///
three_issues == "W I SS" | three_issues == "W SS Ab" | three_issues == "W SS T" 
label var SocialSecurity_inserts "Social Security issue area displayed"

gen Welfare_inserts = 0 
replace Welfare_inserts = 1 if three_issues == "G W Ab" | three_issues == "G W I" | three_issues == "G W SS" | three_issues == "G W T"  |  three_issues == "W Ab T" | three_issues == "W I Ab" | three_issues == "W I SS" | ///
three_issues == "W I T" | three_issues == "W SS Ab" | three_issues == "W SS T" 
label var Welfare_inserts "Welfare issue area displayed"

// EDUCATION LEVEL
tab education
gen HSorLess = 0
replace HSorLess = 1 if education == 1 | education==2
gen SomeColl = 0
replace SomeColl = 1 if education == 3 | education==4
gen College = 0
replace College = 1 if education == 5
gen PostGrad = 0
replace PostGrad = 1 if education == 6


// RACE AND ETHNICITY
tab race // black and hispanic indicators already exist

gen other = 0
replace other = 1 if race == 4 | race==5 | race==6 | race==7 | race==8



// AGE
tab age
gen a18_29 = 0
replace a18_29 = 1 if age < 30
gen a30_39 = 0
replace a30_39 = 1 if age > 29 & age < 40
gen a40_49 = 0
replace a40_49 = 1 if age > 39 & age < 50
gen a50_59 = 0
replace a50_59 = 1 if age > 49 & age < 60
gen a60_69 = 0
replace a60_69 = 1 if age > 59 & age < 70
gen a70_79 = 0
replace a70_79 = 1 if age > 69 & age < 80
gen a80plus = 0
replace a80plus = 1 if age > 79


// INCOME -> MAKE BINS MATCH DONOR BINS
tab income
gen less30k = 0
replace less30k = 1 if income < 6
gen i30k_69k = 0
replace i30k_69k = 1 if income > 5 & income < 10
gen i70k_100k = 0
replace i70k_100k = 1 if income > 9 & income < 12
gen i100k_200k = 0
replace i100k_200k = 1 if income > 11 & income < 15
gen i200k_250k = 0
replace i200k_250k = 1 if income ==15
gen i250kplus = 0
replace i250kplus = 1 if income ==16

// drop vars that are not needed in merged dataset
drop psid Guns_insert_aligned_dem_main Guns_insert_aligned_rep_main Guns_insert_extreme_dem_main Guns_insert_extreme_rep_main Guns_insert_OE_main Taxes_insert_aligned_dem_main ///
Taxes_insert_aligned_rep_main Taxes_insert_extreme_dem_main Taxes_insert_extreme_rep_main Taxes_insert_OE_main SS_insert_aligned_dem_main SS_insert_aligned_rep_main ///
SS_insert_extreme_dem_main SS_insert_extreme_rep_main SS_insert_OE_main Abort_insert_aligned_dem_main Abort_insert_aligned_rep_main Abort_insert_extreme_dem_main ///
Abort_insert_extreme_rep_main Abort_insert_OE_main Welfare_insert_aligned_dem_main Welfare_insert_aligned_rep_main Welfare_insert_extreme_dem_main ///
Welfare_insert_extreme_rep_main Welfare_insert_OE_main ISIS_insert_aligned_dem_main ISIS_insert_aligned_rep_main ISIS_insert_extreme_dem_main ISIS_insert_extreme_rep_main ///
ISIS_insert_OE_main district_competitiveness_main marks_of_competency_main pid_candidate group issue_treatment three_issues ///
group_numeric education race age gender

// rename outcome measures
rename main_primary_vote om_primary
rename main_general_vote om_general

save mass_experiment_pre_append.dta, replace


/// RECODE DONOR DATASETS TO MATCH FOR REGRESSION MODELS

// replaced with data file from the end of 01 Processing Donor Survey Data
clear
use Contributors_SurveyData_Processed_DeIndentified, clear 

//drop pure independents
drop if q5 == 3 | q9 == 3
tab group // should be n = 886 (or 637 without the Unusual treatment)
label var group "Treatment Group, Donors Only"

gen Sample = 2
label var Sample "Which Sample? Mass=1, Donor==2"

* Treatment indicators
gen T_Extreme = 0
replace T_Extreme = 1 if group == "Extreme"
label var T_Extreme "Extreme treatment"

gen T_Unusual = 0
replace T_Unusual = 1 if group == "Unusual"
label var T_Unusual "Unusual treatment"

gen T_Bipartisan = 0
replace T_Bipartisan = 1 if group == "Bipartisan"
label var T_Bipartisan "Bipartisan treatment"

gen T_Aligned = 0
replace T_Aligned = 1 if group == "Aligned"
label var T_Aligned "Aligned treatment"

*saw a dem candidate
gen Dem_cand = 0
replace Dem_cand = 1 if saw_dem == 1
label var Dem_cand "Shown Democratic candidate"

* Partisanship
gen pid3 = .
replace pid3 = -1 if q2==1 | q6==1 | q5==1 | q9==1
replace pid3 = 1 if q2==3 | q6==3 | q5==2 | q9==2
replace pid3 = 0 if q5==3 | q9==3 // 18 independents

gen dem_d = 0
replace dem_d = 1 if pid3 == -1

gen rep_d = 0
replace rep_d = 1 if pid3 == 1

gen ind_d = 0
replace ind_d = 1 if pid3 == 0
label var ind_d "Pure Independents"
//done
gen dem_lean = 0
replace dem_lean = 1 if q5 == 1 | q9 == 1
label var dem_lean "Leaning Democrat"
//done
gen dem_weak = 0
replace dem_weak = 1 if q3 == 2 | q7 ==2
label var dem_weak "Weak Democrat"
//done
gen rep_lean = 0
replace rep_lean = 1 if q5 == 2 | q9 == 2
label var rep_lean "Leaning Republican"
//done
gen rep_weak = 0
replace rep_weak = 1  if q4 == 2 | q8 ==2
label var rep_weak "Weak Republican"
//done
gen rep_strong = 0
replace rep_strong = 1 if q4 == 1 | q8 ==1
label var rep_strong "Strong Republican"
//done
gen dem_strong = 0
replace dem_strong = 1 if q3 == 1 | q7 ==1
label var dem_strong "Strong Democrat"

gen strong_partisan = 0
replace strong_partisan = 1 if dem_strong == 1 | rep_strong == 1
label var strong_partisan "Strong Partisans"

gen weak_partisan = 0
replace weak_partisan = 1 if dem_weak == 1 | rep_weak == 1
label var weak_partisan "Weak Partisans"

gen lean_partisan = 0
replace lean_partisan = 1 if dem_lean == 1 | rep_lean == 1
label var lean_partisan "Lean Partisans"

// dummy vars for marks of competences. for regression, manager with 10 employees is excluded category
gen manager_10_sl = 0
replace manager_10_sl = 1 if experience1 == "a manager of a company with 10 employees and was a member of the state legislature."
label var manager_10_sl "10 Employees, State Legislature"

gen manager_10_cc = 0
replace manager_10_cc = 1 if experience1 == "a manager of a company with 10 employees and was a member of the city council."
label var manager_10_cc "10 Employees, City Council"

gen manager_100 = 0
replace manager_100 = 1 if experience1 == "a manager of a company with 100 employees."
label var manager_100 "100 Employees"

gen manager_100_sl = 0
replace manager_100_sl = 1 if experience1 == "a manager of a company with 100 employees and was a member of the state legislature."
label var manager_100_sl "100 Employees, State Legislature"

gen manager_100_cc = 0
replace manager_100_cc = 1 if experience1 == "a manager of a company with 100 employees and was a member of the city council."
label var manager_100_cc "100 Employees, City Council"

gen manager_1000 = 0
replace manager_1000 = 1 if experience1 == "a manager of a company with 1000 employees."
label var manager_1000 "1000 Employees"

gen manager_1000_sl = 0
replace manager_1000_sl = 1 if experience1 == "a manager of a company with 1000 employees and was a member of the state legislature."
label var manager_1000_sl "1000 Employees, State Legislature"

gen manager_1000_cc = 0
replace manager_1000_cc = 1 if experience1 == "a manager of a company with 1000 employees and was a member of the city council."
label var manager_1000_cc "1000 Employees, City Council"

//generate dummy variable for seeing liberal (conservative) vs. somewhat liberal (conservative) issue positions (1=lib, 0=somewhat lib)
//dems
gen guns_lib_d = 0
replace guns_lib_d = 1 if firstposition_d == "I support no-issue concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." 
replace guns_lib_d = 1 if secondposition_d == "I support no-issue concealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun." 
replace guns_lib_d = 1 if firstposition_d == "I support no-issueconcealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun."
replace guns_lib_d = 1 if secondposition_d == "I support no-issueconcealed carry gun laws. These laws prohibit any private citizens from carrying a concealed handgun."
label var guns_lib_d "Guns: liberal position"

gen taxes_lib_d = 0
replace taxes_lib_d = 1 if firstposition_d == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000."
replace taxes_lib_d = 1 if secondposition_d == "I support raising the top marginal tax rate to 60% for those making more than $1,000,000."
label var taxes_lib_d "Taxes: liberal position"

gen SS_lib_d = 0
replace SS_lib_d = 1 if firstposition_d == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes." 
replace SS_lib_d = 1 if secondposition_d == "To keep Social Security solvent, I support raising the income cap over the next few years from $118,500 to $250,000 so that more money is raised in taxes."
label var SS_lib_d "Social Security: liberal position"

gen Abort_lib_d = 0
replace Abort_lib_d = 1 if firstposition_d == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent."
replace Abort_lib_d = 1 if secondposition_d == "I support making abortion legal during the first trimester of pregnancy for individuals ages 16 years or older without parental consent."
label var Abort_lib_d "Abortion: liberal position"

gen Welfare_lib_d = 0
replace Welfare_lib_d = 1 if firstposition_d == "I support raising the lifetime cap from 5 years to 9 years." 
replace Welfare_lib_d = 1 if secondposition_d == "I support raising the lifetime cap from 5 years to 9 years." 
label var Welfare_lib_d "Welfare: liberal position"

gen ISIS_lib_d = 0
replace ISIS_lib_d = 1 if firstposition_d == "I do not support sending additional air power or any ground troops to Syria and Iraq."
replace ISIS_lib_d = 1 if secondposition_d == "I do not support sending additional air power or any ground troops to Syria and Iraq."
label var ISIS_lib_d "ISIS: liberal position"
//reps
gen guns_con_d = 0
replace guns_con_d = 1 if firstposition_r == "I support unrestrictedconcealed carry gun laws. These laws do not require a permit to carry a concealed handgun."
replace guns_con_d = 1 if secondposition_r == "I support unrestrictedconcealed carry gun laws. These laws do not require a permit to carry a concealed handgun."
replace guns_con_d = 1 if firstposition_r == "I support unrestricted concealed carry gun laws. These laws do not require a permit to carry a concealed handgun."
replace guns_con_d = 1 if secondposition_r == "I support unrestricted concealed carry gun laws. These laws do not require a permit to carry a concealed handgun."
label var guns_con_d "Guns: conservative position"

gen taxes_con_d = 0
replace taxes_con_d = 1 if firstposition_r == "I support reducing the top marginal tax rate to 20%."
replace taxes_con_d = 1 if secondposition_r == "I support reducing the top marginal tax rate to 20%."
label var taxes_con_d "Taxes: conservative position"

gen SS_con_d = 0
replace SS_con_d = 1 if firstposition_r == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%."
replace SS_con_d = 1 if secondposition_r == "To keep Social Security solvent, I support reducing Social Security benefits over the next few years by 10%."
label var SS_con_d "Social Security: conservative position"

gen Abort_con_d = 0
replace Abort_con_d = 1 if firstposition_r == "I support making abortion legal only in cases where the mothers life is in danger."
replace Abort_con_d = 1 if secondposition_r == "I support making abortion legal only in cases where the mothers life is in danger."
label var Abort_con_d "Abortion: conservative position"

gen Welfare_con_d = 0
replace Welfare_con_d = 1 if firstposition_r == "I support reducing the lifetime cap from 5 years to 1 year."
replace Welfare_con_d = 1 if secondposition_r == "I support reducing the lifetime cap from 5 years to 1 year."
label var Welfare_con_d "Welfare: conservative position"

gen ISIS_con_d = 0
replace ISIS_con_d = 1 if firstposition_r == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq."
replace ISIS_con_d = 1 if secondposition_r == "I support sending additional air power and 50,000 U.S. ground troops to Syria and Iraq."
label var ISIS_con_d "ISIS: conservative position"


// generate dummy variables for seeing each issue area
gen Guns_inserts = 0 
replace Guns_inserts = 1 if firstarea_d == "Guns" | secondarea_d == "Guns" | thirdarea_d == "Guns"
replace Guns_inserts = 1 if firstarea_r == "Guns" | secondarea_r == "Guns" | thirdarea_r == "Guns"
label var Guns_inserts "Guns issue area displayed"

gen Abortion_inserts = 0 
replace Abortion_inserts = 1 if firstarea_d == "Abortion" | secondarea_d == "Abortion" | thirdarea_d == "Abortion"
replace Abortion_inserts = 1 if firstarea_r == "Abortion" | secondarea_r == "Abortion" | thirdarea_r == "Abortion"
label var Abortion_inserts "Abortion issue area displayed"

gen Taxes_inserts = 0 
replace Taxes_inserts = 1 if firstarea_d == "Taxes" | secondarea_d == "Taxes" | thirdarea_d == "Taxes"
replace Taxes_inserts = 1 if firstarea_r == "Taxes" | secondarea_r == "Taxes" | thirdarea_r == "Taxes"
label var Taxes_inserts "Taxes issue area displayed"

gen ISIS_inserts = 0 
replace ISIS_inserts = 1 if firstarea_d == "ISIS" | secondarea_d == "ISIS" | thirdarea_d == "ISIS"
replace ISIS_inserts = 1 if firstarea_r == "ISIS" | secondarea_r == "ISIS" | thirdarea_r == "ISIS"
label var ISIS_inserts "ISIS issue area displayed"

gen SocialSecurity_inserts = 0 
replace SocialSecurity_inserts = 1 if firstarea_d == "Social Security" | secondarea_d == "Social Security" | thirdarea_d == "Social Security"
replace SocialSecurity_inserts = 1 if firstarea_r == "Soc Security" | secondarea_r == "Soc Security" | thirdarea_r == "Soc Security"
label var SocialSecurity_inserts "Social Security issue area displayed"

gen Welfare_inserts = 0 
replace Welfare_inserts = 1 if firstarea_d == "Welfare" | secondarea_d == "Welfare" | thirdarea_d == "Welfare"
replace Welfare_inserts = 1 if firstarea_r == "Welfare" | secondarea_r == "Welfare" | thirdarea_r == "Welfare"
label var Welfare_inserts "Welfare issue area displayed"

// EDUCATION LEVEL
tab q27
rename q27 education
gen HSorLess = 0
replace HSorLess = 1 if education == 1 | education==2
gen SomeColl = 0
replace SomeColl = 1 if education == 3 | education==4
gen College = 0
replace College = 1 if education == 5
gen PostGrad = 0
replace PostGrad = 1 if education == 6

gen female = 0
replace female = 1 if q30 ==2

// RACE AND ETHNICITY
tab q28
rename q28 race
gen black = 0
replace black = 1 if race == 2

gen other = 0
replace other = 1 if race == 4 | race==5 | race==6 | race==7 | race==8

gen hispanic = 0
replace hispanic = 1 if race == 3

gen white = 0
replace white = 1 if race == 1

// AGE
tab q29
gen age = 2017 - q29
label var age "Age (calculated from asking year of birth)"
tab age
gen a18_29 = 0
replace a18_29 = 1 if age < 30
gen a30_39 = 0
replace a30_39 = 1 if age > 29 & age < 40
gen a40_49 = 0
replace a40_49 = 1 if age > 39 & age < 50
gen a50_59 = 0
replace a50_59 = 1 if age > 49 & age < 60
gen a60_69 = 0
replace a60_69 = 1 if age > 59 & age < 70
gen a70_79 = 0
replace a70_79 = 1 if age > 69 & age < 80
gen a80plus = 0
replace a80plus = 1 if age > 79

// IDEOLOGY
gen liberal = 0
replace liberal = 1 if q10 == 2 | q12 == 2
label var liberal "Liberal"

gen very_liberal = 0
replace very_liberal = 1 if q10 == 1 | q12 == 1
label var very_liberal "Very Liberal"

gen lean_liberal = 0
replace lean_liberal = 1 if q11 == 1 | q13 == 1
label var lean_liberal "Lean Liberal"

gen conservative = 0
replace conservative = 1 if q10 == 4 | q12 == 4
label var conservative "Conservative"

gen very_conservative = 0
replace very_conservative = 1 if q10 == 5 | q12 == 5
label var very_conservative "Very Conservative"

gen lean_conservative = 0
replace lean_conservative = 1 if q11 == 2 | q13 == 2
label var lean_conservative "Lean Conservative"

gen pure_moderate = 0
replace pure_moderate = 1 if q11 == 3 | q13 == 3
label var pure_moderate "Pure Moderate"

//FOLDED IDEOLOGY -> these are used in appendix Tables A7 and A8
gen very_libcon = 0
replace very_libcon = 1 if very_liberal == 1 | very_conservative == 1
label var very_libcon "Very Lib/Con"

gen libcon = 0
replace libcon = 1 if liberal == 1 | conservative == 1
label var libcon "Liberal/Conservative"

gen lean_libcon = 0
replace lean_libcon = 1 if lean_liberal == 1 | lean_conservative == 1
label var lean_libcon "Lean Lib/Con"

// INCOME -> MAKE BINS MATCH DONOR BINS
rename q31 income
tab income
gen less30k = 0
replace less30k = 1 if income ==5
gen i30k_69k = 0
replace i30k_69k = 1 if income == 6
gen i70k_100k = 0
replace i70k_100k = 1 if income ==8
gen i100k_200k = 0
replace i100k_200k = 1 if income == 15 | income == 12 | income == 14
gen i200k_250k = 0
replace i200k_250k = 1 if income ==13
gen i250kplus = 0
replace i250kplus = 1 if income ==11 | income ==9 | income==16



egen primary = rowmax(q44 q63)
label var primary "Primary Voting (0-100)"
replace primary = . if primary==-99  

egen contribute_inp = rowmax(q45 q64)
label var contribute_inp "In District: Likelihood of Contributing (0-100)"
replace contribute_inp = . if contribute_inp==-99  

egen contribute_outp = rowmax(q46 q65)
label var contribute_outp "Out District: Likelihood of Contributing (0-100)"
replace contribute_outp = . if contribute_outp==-99   

egen general = rowmax(q48 q67)
label var general "Out District: Likelihood of Contributing (0-100)"
replace general = . if general==-99   

egen contribute_ing = rowmax(q49 q68)
label var contribute_ing "Out District: Likelihood of Contributing (0-100)"
replace contribute_ing = . if contribute_ing==-99   

egen contribute_outg = rowmax(q50 q69)
label var contribute_outg "Out District: Likelihood of Contributing (0-100)"
replace contribute_outg = . if contribute_outg==-99   

// rename outcome measures
rename primary om_primary
rename contribute_inp om_in_district_primary_contrib
rename contribute_outp om_out_district_primary_contrib 
rename general om_general
rename contribute_ing om_in_district_general_contrib 
rename contribute_outg om_out_district_general_contrib


drop firstposition_d secondposition_d thirdposition_d fourthposition_d fifthposition_d sixthposition_d psid firstarea_d secondarea_d thirdarea_d ///
fourtharea_d fiftharea_d sixtharea_d firstlong_d secondlong_d thirdlong_d fourthlong_d fifthlong_d sixthlong_d firstshort_d secondshort_d thirdshort_d fourthshort_d fifthshort_d ///
sixthshort_d firstposition_r secondposition_r thirdposition_r fourthposition_r fifthposition_r sixthposition_r firstarea_r secondarea_r thirdarea_r fourtharea_r fiftharea_r ///
sixtharea_r firstlong_r secondlong_r thirdlong_r fourthlong_r fifthlong_r sixthlong_r firstshort_r secondshort_r thirdshort_r fourthshort_r fifthshort_r sixthshort_r ed ///
nojavascript israndomized experience1 experience2 election1 election2 q117 qcell2 qtiming_1 qtiming_2 qtiming_3 qtiming_4 q173 q174 q175_1 q175_2 q175_3 q175_4 q176 q1 ///
q2 q3 q4 q5 q6 q7 q8 q9 q10 q11 q12 q13 q14 q15 q16_1 q17 q18 q19_1 q20_1 q20_2 q20_3 q20_4 q20_5 q20_6 q20_7 q20_8 q21_1 q21_2 q21_3 q21_4 q21_5 q21_6 q21_7 q21_8 q21_9 ///
q21_10 q21_11 q22 q23_1 q24_1 q25 q26 education race q28_text q29 q30 income q32 q35 q51 q69 q701_1 q701_2 q701_3 q701_4 q701_5 q701_6 q702_1 q702_2 q702_3 q702_4 q702_5 ///
q702_6 q71 q71_text q72 q73 q74 q75 q76 q77 q78 q79 q117_1 q117_1_text q117_2 q117_2_text q172 q33_1 q34 q36 q37 q38 q39 q40 q41 q42 q43 q44_1 q45_1 q46_1 q47_1 q48_1 ///
q49_1 q50_1 q52_1 q53 q54 q55 q56 q57 q58 q59 q60 q61 q62 q63_1 q64_1 q65_1 q66_1 q67_1 q68_1 q69_1 age saw_dem 

tab group // make sure I haven't lost anybody
save donor_experiment_pre_append.dta, replace

//////////////////////////////////////////////////////////
// APPEND MASS AND DONOR SURVEYS, FINAL ANALYSIS RECODES
//////////////////////////////////////////////////////////

use donor_experiment_pre_append, clear 
append using mass_experiment_pre_append 
save mass_and_donor_experiments, replace

//Creates numeric of randomized electoral condition
gen election_win = 0
replace election_win = 1 if election =="win"

gen election_tossup = 0
replace election_tossup = 1 if election =="toss up"

// Create indicators and interactions for regression models
gen donor_d = 0
replace donor_d=1 if Sample==2

// Treatment interacted with donor status
gen extr_donor = T_Extreme*donor_d
gen unus_donor = T_Unusual*donor_d
gen bipa_donor = T_Bipartisan*donor_d

//Treatment interacted with partisanship
gen extr_strpart = T_Extreme* strong_partisan
gen unus_strpart = T_Unusual* strong_partisan
gen bipa_strpart = T_Bipartisan* strong_partisan

gen extr_wpart = T_Extreme* weak_partisan
gen unus_wpart = T_Unusual* weak_partisan
gen bipa_wpart = T_Bipartisan* weak_partisan

//demo*treatment interactions for regression models
//extreme treatment interactions
gen T_Extreme_SC = T_Extreme*SomeColl
gen T_Extreme_C = T_Extreme*College
gen T_Extreme_PG = T_Extreme*PostGrad
gen T_Extreme_f = T_Extreme*female
gen T_Extreme_b = T_Extreme*black
gen T_Extreme_h = T_Extreme*hispanic
gen T_Extreme_ot = T_Extreme*other
gen T_Extreme_a1 = T_Extreme*a30_39
gen T_Extreme_a2 = T_Extreme*a40_49
gen T_Extreme_a3 = T_Extreme*a50_59
gen T_Extreme_a4 = T_Extreme*a60_69
gen T_Extreme_a5 = T_Extreme*a70_79
gen T_Extreme_a6 = T_Extreme*a80plus
gen T_Extreme_i2 = T_Extreme*i30k_69k
gen T_Extreme_i3 = T_Extreme*i70k_100k
gen T_Extreme_i4 = T_Extreme*i100k_200k
gen T_Extreme_i5 = T_Extreme*i200k_250k
gen T_Extreme_i6 = T_Extreme*i250kplus
// bipartisan treatment interactions
gen T_Bipartisan_SC = T_Bipartisan*SomeColl
gen T_Bipartisan_C = T_Bipartisan*College
gen T_Bipartisan_PG = T_Bipartisan*PostGrad
gen T_Bipartisan_f = T_Bipartisan*female
gen T_Bipartisan_b = T_Bipartisan*black
gen T_Bipartisan_h = T_Bipartisan*hispanic
gen T_Bipartisan_ot = T_Bipartisan*other
gen T_Bipartisan_a1 = T_Bipartisan*a30_39
gen T_Bipartisan_a2 = T_Bipartisan*a40_49
gen T_Bipartisan_a3 = T_Bipartisan*a50_59
gen T_Bipartisan_a4 = T_Bipartisan*a60_69
gen T_Bipartisan_a5 = T_Bipartisan*a70_79
gen T_Bipartisan_a6 = T_Bipartisan*a80plus
gen T_Bipartisan_i2 = T_Bipartisan*i30k_69k
gen T_Bipartisan_i3 = T_Bipartisan*i70k_100k
gen T_Bipartisan_i4 = T_Bipartisan*i100k_200k
gen T_Bipartisan_i5 = T_Bipartisan*i200k_250k
gen T_Bipartisan_i6 = T_Bipartisan*i250kplus
// Drop both mass and donors who saw the unusual treatment (not analyzed in this paper)
drop if T_Unusual ==1


// dataset ready for analysis
save mass_and_donor_experiments_FINAL, replace
