// Andrew Gooch and Greg Huber
// How Issue Positions Affect Candidate Performance
// July 2018

// This do file creates Figures 2-5. 
// The first two figures are donors only, and the second two figures are donors and the mass public
// Figures include means and 95 percent confidence intervals
set more off
clear
cd "C:\Users\[Replication File Name]"
use Data\mass_and_donor_experiments_FINAL
set scheme s2color

//reverse sample indicator so Donors are on the left side of the plot
gen exp_group = 1 if Sample ==2
replace exp_group = 2 if Sample ==1
label var exp_group " "
label define exp_group 1 "Donor Sample" 2 "Mass Public Sample"  
label values exp_group exp_group 
tab exp_group


//////////////////////////////////////////////////////////
// Figure 2: CONTRIBUTING IN DISTRICT: Donors only
/////////////////////////////////////////////////////////

// variables that capture responses to general election voting by treatment condition
// these variables can be used in the function ciplot

// Willingness to Contribute In District in a Primary Election
gen contribute_inp_g1 = om_in_district_primary_contrib if group=="Aligned" & donor_d==1
label var contribute_inp_g1 "Aligned"
gen contribute_inp_g2 = om_in_district_primary_contrib if group=="Extreme" & donor_d==1
label var contribute_inp_g2 "Extreme"
gen contribute_inp_g3 = om_in_district_primary_contrib if group=="Bipartisan" & donor_d==1
label var contribute_inp_g3 "Bipartisan"

// Figure 2, Left Panel
ciplot contribute_inp_g1 contribute_inp_g2 contribute_inp_g3, graphregion(color(white)) title("In District, Primary Election") inclusive ylabel (20(10) 70)  note(" ") ///
xlabel(,labsize(med)) saving(Figure2_left, replace)

// Willingness to Contribute Out of District in a General Election
gen contribute_ing_g1 = om_in_district_general_contrib if group=="Aligned" & donor_d==1
label var contribute_ing_g1 "Aligned"
gen contribute_ing_g2 = om_in_district_general_contrib if group=="Extreme" & donor_d==1
label var contribute_ing_g2 "Extreme"
gen contribute_ing_g3 = om_in_district_general_contrib if group=="Bipartisan" & donor_d==1
label var contribute_ing_g3 "Bipartisan"

// Figure 2, Right Panel
ciplot contribute_ing_g1 contribute_ing_g2 contribute_ing_g3, graphregion(color(white)) title("In District, General Election") inclusive ylabel(20(10) 70) note(" ") ///
xlabel(,labsize(med)) saving(Figure2_right, replace)

// Makes Figure 3 combining both panels
gr combine Figure2_left.gph Figure2_right.gph, graphregion(color(white)) col(2) note("Note: Average evaluation of each randomized House candidate with 95% confidence intervals") l1title("Likelihood of Contributing (0-100)") 
graph export Figure_2.png, replace
cap erase Figure2_left.gph
cap erase Figure2_right.gph

//////////////////////////////////////////////////////////
// Figure 3: CONTRIBUTING OUT OF DISTRICT: Donors only
/////////////////////////////////////////////////////////

// variables that capture responses to general election voting by treatment condition
// these variables can be used in the function ciplot

// Willingness to Contribute Out of District in a Primary Election
gen contribute_outp_g1 = om_out_district_primary_contrib if group=="Aligned" & donor_d==1
label var contribute_outp_g1 "Aligned"
gen contribute_outp_g2 = om_out_district_primary_contrib if group=="Extreme" & donor_d==1
label var contribute_outp_g2 "Extreme"
gen contribute_outp_g3 = om_out_district_primary_contrib if group=="Bipartisan" & donor_d==1
label var contribute_outp_g3 "Bipartisan"
  
// Figure 3, Left Panel
ciplot contribute_outp_g1 contribute_outp_g2 contribute_outp_g3 ///
, graphregion(color(white)) title("Out District, Primary Election") inclusive ylabel (0(10) 40)  note(" ") ///
xlabel(,labsize(med)) saving(Figure3_left, replace)

// Willingness to Contribute Out of District in a General Election
gen contribute_outg_g1 = om_out_district_general_contrib if group=="Aligned" & donor_d==1
label var contribute_outg_g1 "Aligned"
gen contribute_outg_g2 = om_out_district_general_contrib if group=="Extreme" & donor_d==1
label var contribute_outg_g2 "Extreme"
gen contribute_outg_g3 = om_out_district_general_contrib if group=="Bipartisan" & donor_d==1
label var contribute_outg_g3 "Bipartisan"

// Figure 3, Right Panel
ciplot contribute_outg_g1 contribute_outg_g2 contribute_outg_g3 ///
, graphregion(color(white)) title("Out District, General Election") inclusive ylabel(0(10) 40) note(" ") ///
xlabel(,labsize(med)) saving(Figure3_right, replace)

// Makes Figure 3 combining both panels
gr combine Figure3_left.gph Figure3_right.gph, graphregion(color(white)) col(2) note("Note: Average evaluation of each randomized House candidate with 95% confidence intervals") l1title("Likelihood of Contributing (0-100)") 
graph export Figure_3.png, replace
cap erase Figure3_left.gph
cap erase Figure3_right.gph

/////////////////////////////////////////////////
// Figure 4: PRIMARY VOTING: Donors and Mass
////////////////////////////////////////////////

// variables that capture responses to general election voting by treatment condition
// these variables can be used in the function ciplot
gen primary_g1 = om_primary if T_Aligned==1
label var primary_g1 "Aligned Candidate"
gen primary_g2 = om_primary if T_Extreme==1
label var primary_g2 "Extreme Candidate"
gen primary_g3 = om_primary if T_Bipartisan==1
label var primary_g3 "Bipartisan Candidate"

// FIGURE 4
ciplot primary_g1 primary_g2 primary_g3, by(exp_group) inclusive ytitle("Primary Election Vote Choice (0-100)") ylabel(40(5) 70)  ///
note("Note: Average evaluation of each randomized House candidate with 95% confidence intervals") graphregion(color(white)) xlabel(,labsize(small)) legend(rows(1) size(small)) //saving(Figure_4, replace) 
graph export Figure_4.png, replace

/////////////////////////////////////////////////
// Figure 5: GENERAL VOTING: Donors and Mass
////////////////////////////////////////////////

// variables that capture responses to general election voting by treatment condition
// these variables can be used in the function ciplot
gen general_g1 = om_general if T_Aligned==1
label var general_g1 "Aligned Candidate"
gen general_g2 = om_general if T_Extreme==1
label var general_g2 "Extreme Candidate"
gen general_g3 = om_general if T_Bipartisan==1
label var general_g3 "Bipartisan Candidate"

// FIGURE 5
ciplot general_g1 general_g2 general_g3, by(exp_group) inclusive ytitle("General Election Vote Choice (0-100)") ylabel(55(5) 100) ///
note("Note: Average evaluation of each randomized House candidate with 95% confidence intervals") graphregion(color(white)) xlabel(,labsize(small)) legend(rows(1) size(small)) //saving(Figure_5, replace)
graph export Figure_5.png, replace
