// Andrew Gooch and Greg Huber
// How Issue Positions Affect Candidate Performance
// July 2018

// This code appends the mass public survey with the donors survey
// Before appending, both data files recode variables to match both data files
// Recodes also include indicator variables for the two regression models (primary and general election voting)
// Finaly, a new DTA file is created with both mass public and donor respondents, which is then used to create the main analysis: Figures 2 to 5 and Tables 3 and 4


set more off 

//cd "C:\Users\[Replication File Name]"
cd "C:\Users\[Replication File Name]"
use Data\mass_and_donor_experiments_FINAL.dta, clear


//////////////////////////////////////////////////////////
// TABLE 3: PRIMARY ELECTION VOTING, 3 COLUMNS
/////////////////////////////////////////////////////////
// Note, Table 3 in paper only displays relevant interactions. The code below makes the full regrssion table see in Appendix Table A5

summ om_primary if T_Aligned ==1

//  donor interaction only
reg om_primary T_Extreme T_Bipartisan donor_d extr_donor bipa_donor  ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc 
outreg2 using Table_3.doc, replace ctitle(Donor Interaction) bracket 

// donor and party strength interactions
reg om_primary T_Extreme T_Bipartisan donor_d extr_donor bipa_donor  ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
extr_strpart bipa_strpart extr_wpart bipa_wpart 
outreg2 using Table_3.doc, append ctitle(Donor and Partisanship Interaction) bracket 

// donor, party strength, and demographic interactions
reg om_primary T_Extreme T_Bipartisan donor_d extr_donor bipa_donor  ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
extr_strpart bipa_strpart extr_wpart bipa_wpart ///
T_Extreme_SC T_Extreme_C T_Extreme_PG T_Extreme_f T_Extreme_b T_Extreme_h T_Extreme_ot T_Extreme_a1 T_Extreme_a2 T_Extreme_a3 T_Extreme_a4 T_Extreme_a5 T_Extreme_a6 T_Extreme_i2 T_Extreme_i3 T_Extreme_i4 T_Extreme_i5 T_Extreme_i6 ///
T_Bipartisan_SC T_Bipartisan_C T_Bipartisan_PG T_Bipartisan_f T_Bipartisan_b T_Bipartisan_h T_Bipartisan_ot T_Bipartisan_a1 T_Bipartisan_a2 T_Bipartisan_a3 T_Bipartisan_a4 T_Bipartisan_a5 T_Bipartisan_a6 T_Bipartisan_i2 T_Bipartisan_i3 T_Bipartisan_i4 T_Bipartisan_i5 T_Bipartisan_i6 
outreg2 using Table_3.doc, append ctitle(Donor, Partisanship, and Demographics Interaction) bracket 

//////////////////////////////////////////////////////////
// TABLE 4: GENERAL ELECTION VOTING, 3 COLUMNS
/////////////////////////////////////////////////////////
// Note, Table 4 in paper only displays relevant interactions. The code below makes the full regrssion table see in Appendix Table A6

summ om_general if T_Aligned ==1
// general election// donor interaction only
reg om_general T_Extreme T_Bipartisan donor_d extr_donor bipa_donor  ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc 
outreg2 using Table_4.doc,  ctitle(Donor Interaction) bracket 

// donor and party strength interactions
reg om_general T_Extreme T_Bipartisan donor_d extr_donor bipa_donor  ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
extr_strpart bipa_strpart extr_wpart bipa_wpart 
outreg2 using Table_4.doc, append ctitle(Donor and Partisanship Interaction) bracket 

// donor, party strength, and demographic interactions
reg om_general T_Extreme T_Bipartisan donor_d extr_donor bipa_donor  ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc ///
extr_strpart bipa_strpart extr_wpart bipa_wpart ///
T_Extreme_SC T_Extreme_C T_Extreme_PG T_Extreme_f T_Extreme_b T_Extreme_h T_Extreme_ot T_Extreme_a1 T_Extreme_a2 T_Extreme_a3 T_Extreme_a4 T_Extreme_a5 T_Extreme_a6 T_Extreme_i2 T_Extreme_i3 T_Extreme_i4 T_Extreme_i5 T_Extreme_i6 ///
T_Bipartisan_SC T_Bipartisan_C T_Bipartisan_PG T_Bipartisan_f T_Bipartisan_b T_Bipartisan_h T_Bipartisan_ot T_Bipartisan_a1 T_Bipartisan_a2 T_Bipartisan_a3 T_Bipartisan_a4 T_Bipartisan_a5 T_Bipartisan_a6 T_Bipartisan_i2 T_Bipartisan_i3 T_Bipartisan_i4 T_Bipartisan_i5 T_Bipartisan_i6 
outreg2 using Table_4.doc, append ctitle(Donor, Partisanship, and Demographics Interaction) bracket 

/////////////////////////////////////////////////////////////////////////////////////////////////////////
// TABLE A7 and A8 (Appendix): PRIMARY and GENERAL ELECTION VOTING BY IDEOLOGICAL INTENSITY, 3 COLUMNS
//////////////////////////////////////////////////////////////////////////////////////////////////////////

// Donors Only
// These regressions test ideological proximity of donors to the candidates (reviewer request)
// We restrict the sample to donors because they exhibited the most sensitivity to issue positions in the main analysis
// Ideologiy is folded by intensity so that "very" liberal and "very" conserviative are combined (column 1), liberal and conservative are combined (column 2), and moderates by itself (column 3).
set more off 
clear
use Data/mass_and_donor_experiments_FINAL
drop if Sample ==1 // dropping mass public 

///////////////////////
// Primary Voting
///////////////////////

// Very lib/con
reg om_primary T_Extreme T_Bipartisan ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc if very_libcon ==1
outreg2 using Table_A7.doc, append ctitle(Very Liberal/Very Conservative) bracket 
summ om_primary if very_libcon ==1

// liberal/conservative
reg om_primary T_Extreme T_Bipartisan ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc if libcon ==1
outreg2 using Table_A7.doc, append ctitle(Liberal/Conservative) bracket 
summ om_primary if libcon ==1

//moderate
reg om_primary T_Extreme T_Bipartisan ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc if pure_moderate ==1 | lean_liberal ==1 | lean_conservative ==1
outreg2 using Table_A7.doc, append ctitle(Moderate) bracket 
summ om_primary if pure_moderate ==1 | lean_liberal ==1 | lean_conservative == 1


///////////////////////
// General Voting
///////////////////////

// Very lib/con
reg om_general T_Extreme T_Bipartisan ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc if very_libcon ==1
outreg2 using Table_A8.doc, append ctitle(Very Liberal/Very Conservative) bracket 
summ om_general if very_libcon ==1

// liberal/conservative
reg om_general T_Extreme T_Bipartisan ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc if libcon ==1
outreg2 using Table_A8.doc, append ctitle(Liberal/Conservative) bracket 
summ om_general if libcon ==1

//moderate
reg om_general T_Extreme T_Bipartisan ///
Dem_cand strong_partisan weak_partisan ///
SomeColl College PostGrad female black hispanic other ///
a30_39 a40_49 a50_59 a60_69 a70_79 a80plus ///
i30k_69k i70k_100k i100k_200k i200k_250k i250kplus ///
Abortion_inserts Guns_inserts Taxes_inserts SocialSecurity_inserts Welfare_inserts ///
Abort_lib_d guns_lib_d taxes_lib_d SS_lib_d Welfare_lib_d ///
Abort_con_d guns_con_d taxes_con_d SS_con_d Welfare_con_d ///
election_tossup election_win ///
manager_10_sl manager_10_cc manager_100 manager_100_sl manager_100_cc manager_1000 manager_1000_sl manager_1000_cc if pure_moderate ==1 | lean_liberal ==1 | lean_conservative ==1
outreg2 using Table_A8.doc, append ctitle(Moderate) bracket 
summ om_general if pure_moderate ==1 | lean_liberal ==1 | lean_conservative == 1

